Installation — CGDAT 2.0.0-2-g2917492 documentation

# Installation

## Install the package using the installer script

1. Download the zip file from the git github.

2. Navigate to the CGDAT main folder and click the `install.bat` file.

   > - The program and its decencies are now installed.

## Build and install the package yourself

1. Open the command prompt at the main cgdat folder.
2. Run the python setup.py build cmd.
3. When the build is complete run the python setup.py install cmd.

## Create a windows shortcut

1. Open the console and run the `cgdat-shortcut` command.

   > - A shortcut will now be created on the desktop.